@@ -1,4 +1,3 @@
-from __future__ import annotations
 
 __all__ = ['PlanDesign']
 
@@ -7,15 +6,11 @@ import logging
 import numpy as np
 import pydicom
 
-from typing import TYPE_CHECKING
-
-if TYPE_CHECKING:
-    from opentps.core.data.CTCalibrations._abstractCTCalibration import AbstractCTCalibration
-    from opentps.core.data.images._ctImage import CTImage
-    from opentps.core.data.images._roiMask import ROIMask
-    from opentps.core.data.plan import _rangeShifter
-    from opentps.core.processing.imageProcessing import resampler3D
-
+from opentps.core.data.CTCalibrations._abstractCTCalibration import AbstractCTCalibration
+from opentps.core.data.images._ctImage import CTImage
+from opentps.core.data.images._roiMask import ROIMask
+from opentps.core.data.plan import _rangeShifter
+from opentps.core.processing.imageProcessing import resampler3D
 from opentps.core.data._patientData import PatientData
 from opentps.core.data.plan._objectivesList import ObjectivesList
 from opentps.core.processing.planOptimization.planInitializer import PlanInitializer
