@@ -12,24 +12,27 @@ import pydicom
 import scipy.sparse as sp
 from scipy.sparse import csc_matrix
 
-from opentps.core.data.CTCalibrations.MCsquareCalibration._mcsquareCTCalibration import MCsquareCTCalibration
-from opentps.core.data.CTCalibrations.MCsquareCalibration._mcsquareMaterial import MCsquareMaterial
-from opentps.core.data.CTCalibrations.MCsquareCalibration._mcsquareMolecule import MCsquareMolecule
-from opentps.core.data.CTCalibrations._abstractCTCalibration import AbstractCTCalibration
-from opentps.core.data.images._ctImage import CTImage
-from opentps.core.data.images._doseImage import DoseImage
-from opentps.core.data.images._roiMask import ROIMask
-from opentps.core.data.MCsquare._bdl import BDL
-from opentps.core.data.MCsquare._mcsquareConfig import MCsquareConfig
-from opentps.core.data.plan._objectivesList import ObjectivesList
-from opentps.core.data.plan._planIonBeam import PlanIonBeam
-from opentps.core.data.plan._planIonLayer import PlanIonLayer
-from opentps.core.data.plan._rangeShifter import RangeShifter
-from opentps.core.data.plan._rtPlan import RTPlan
-from opentps.core.data._sparseBeamlets import SparseBeamlets
+from opentps.core.data.CTCalibrations.MCsquareCalibration import MCsquareCTCalibration
+from opentps.core.data.CTCalibrations.MCsquareCalibration import MCsquareMaterial
+from opentps.core.data.CTCalibrations.MCsquareCalibration import MCsquareMolecule
+from opentps.core.data.CTCalibrations import AbstractCTCalibration
+from opentps.core.data.images import CTImage
+from opentps.core.data.images import DoseImage
+from opentps.core.data.images import ROIMask
+from opentps.core.data.MCsquare import BDL
+from opentps.core.data.MCsquare import MCsquareConfig
+from opentps.core.data.plan import ObjectivesList
+from opentps.core.data.plan import PlanIonBeam
+from opentps.core.data.plan import PlanIonLayer
+from opentps.core.data.plan import RangeShifter
+from opentps.core.data.plan import RTPlan
+from opentps.core.data import SparseBeamlets
 from opentps.core.io import mhdIO
 from opentps.core.io.mhdIO import exportImageMHD, importImageMHD
 
+from opentps.core.data.images import Image3D
+
+
 logger = logging.getLogger(__name__)
 
 def readBeamlets(file_path, beamletRescaling:Sequence[float], roi: Optional[ROIMask] = None):
@@ -207,18 +210,24 @@ def _print_memory_usage(BeamletMatrix):
         logger.info("Memory usage: {} GB".format(mat_size / 1024 ** 3))
 
 
-def readDose(filePath):
-    doseMHD = importImageMHD(filePath)
-
-    # Convert data for compatibility with MCsquare
-    # These transformations may be modified in a future version
-    doseMHD.imageArray = np.flip(doseMHD.imageArray, 0)
-    doseMHD.imageArray = np.flip(doseMHD.imageArray, 1)
+def readDose(filePath)->DoseImage:
+    doseMHD = readMCsquareMHD(filePath)
 
     doseImage = DoseImage.fromImage3D(doseMHD)
 
     return doseImage
 
+def readMCsquareMHD(filePath) -> Image3D:
+    image = importImageMHD(filePath)
+
+    # Convert data for compatibility with MCsquare
+    # These transformations may be modified in a future version
+    image.imageArray = np.flip(image.imageArray, 0)
+    image.imageArray = np.flip(image.imageArray, 1)
+
+    return image
+
+
 def readMCsquarePlan(ct: CTImage, file_path):
     destFolder, destFile = os.path.split(file_path)
     fileName, fileExtension = os.path.splitext(destFile)
@@ -611,7 +620,7 @@ def writeObjectives(objectives: ObjectivesList, file_path):
 
     logger.info("Write plan objectives: {}".format(file_path))
     fid = open(file_path, 'w');
-    fid.write("# List of objectives for treatment plan optimization\n\n")
+    fid.write("# List of objectives for treatment plan planOptimization\n\n")
     fid.write("Target_ROIName:\n" + targetName + "\n\n")
     fid.write("Dose_prescription:\n" + str(objectives.targetPrescription) + "\n\n")
     fid.write("Number_of_objectives:\n" + str(len(objectives.fidObjList)) + "\n\n")
